@@ -1305,6 +1305,8 @@ hd_wm_window_set_icon_geometry (HDWMWindow *win,
                    XA_CARDINAL, 32, PropModeReplace,
                    (guchar *)&data, 4);
 
-  gdk_error_trap_pop ();
+  gdk_flush ();
+  if (gdk_error_trap_pop ())
+    g_warning ("X Error when changing Icon geometry");
 }
 
