@@ -349,7 +349,7 @@ hd_wm_prepare_close_application_dialog (HDWM *hdwm, HDWMCADAction action, gboole
     HDWMCADItem *item;
 
     info = HD_WM_ENTRY_INFO (l->data);
-    win = HD_WM_IS_WINDOW (info) ? HD_WM_WINDOW (info) : NULL;
+    win = hd_wm_application_get_active_window (HD_WM_APPLICATION (info));
 
     if (win == NULL)
     {
@@ -359,7 +359,7 @@ hd_wm_prepare_close_application_dialog (HDWM *hdwm, HDWMCADAction action, gboole
       continue;
     }
 
-    app = hd_wm_window_get_application(win);
+    app = HD_WM_APPLICATION (info);
       
     if (app == NULL)
     {
@@ -1121,6 +1121,8 @@ hd_wm_init (HDWM *hdwm)
   memset(hdwm->priv, 0, sizeof(HDWMPrivate));
 
   hdwm->priv->init_dbus = TRUE;
+
+  hdwm->priv->lowmem_situation = FALSE;
   
   /* Check for configurable lowmem values. */
 
