@@ -312,7 +312,9 @@ hd_switcher_menu_create_separator (gboolean is_application_menu)
     gtk_widget_set_name (separator, HD_SWITCHER_MENU_APP_MENU_ITEM_NAME);
   else
     gtk_widget_set_name (separator, HD_SWITCHER_MENU_NOT_MENU_ITEM_NAME);
-	  
+
+  gtk_widget_show (separator);
+  
   return separator;
 }
 
@@ -1402,7 +1404,7 @@ hd_switcher_menu_create_clear_notifications_button (HDSwitcherMenu *switcher)
   gtk_container_add (GTK_CONTAINER (switcher->priv->clear_events_menu_item), 
       	       hbox);
 
-  gtk_widget_show_all (hbox);
+  gtk_widget_show_all (switcher->priv->clear_events_menu_item);
 
   g_signal_connect_after (G_OBJECT (switcher->priv->clear_events_menu_item),
                           "activate",
