@@ -1352,11 +1352,9 @@ hn_app_switcher_close_application_dialog (HDWM *hdwm, HDWMCADAction action, GLis
   /* Collect open applications */
   for (l = items; l; l = l->next)
   {
-    const gchar *icon_name;
     GtkWidget *image;
     GtkWidget *label;
     GdkPixbuf *icon = NULL;
-    GtkIconTheme *icon_theme;
     HDWMApplication *app;
     HDWMCADItem *item = (HDWMCADItem *) l->data;
     
@@ -1369,24 +1367,9 @@ hn_app_switcher_close_application_dialog (HDWM *hdwm, HDWMCADAction action, GLis
       continue;
       
     label = gtk_label_new (_(hd_wm_application_get_name (app)));
-    icon_name = hd_wm_application_get_icon_name(app);
-    icon_theme = gtk_icon_theme_get_default ();
+   
+    icon = hd_wm_entry_info_get_app_icon (HD_WM_ENTRY_INFO (app), ICON_SIZE, NULL);
     
-    if (icon_name)
-      icon = gtk_icon_theme_load_icon (icon_theme,
-                                       icon_name,
-                                       ICON_SIZE,
-                                       GTK_ICON_LOOKUP_NO_SVG,
-                                       NULL);
-
-    if (!icon)
-      icon = gtk_icon_theme_load_icon (icon_theme,
-                                       AS_MENU_DEFAULT_APP_ICON,
-                                       ICON_SIZE,
-                                       GTK_ICON_LOOKUP_NO_SVG,
-                                       NULL);
-      
-
     image = gtk_image_new_from_pixbuf (icon);
     if (icon)
       gdk_pixbuf_unref (icon);
